/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.adapter;

import java.sql.Connection;
import java.sql.SQLException;

import org.objectweb.jorm.mapper.rdb.adapter.api.RdbAdapterException;

/**
 * Adapter for the database Progress 9.1D server
 * 
 * @author Pascal Gos
 */
public class ProgressAdapter extends BasicRdbAdapter {

    private static int DEFAULT_VARCHAR_SIZE = 256;

    public ProgressAdapter() {
        super("PROGRESS");
    }

    public String getCreateSequence(String seqName)
            throws UnsupportedOperationException {
        throw new UnsupportedOperationException(
                "Sequence creation is only possible with DataDictionary");
    }

    public String getCreateSequence(String seqName, Integer startid,
            Integer inc, Integer cache) throws UnsupportedOperationException {
        throw new UnsupportedOperationException(
                "Sequence creation is only possible with DataDictionary");
    }

    public boolean existSequence(Connection connection, String seqName)
            throws SQLException {
        return true;
    }

    public String getSqlType(int typeCode, boolean usedInPK, int size, int scale)
            throws RdbAdapterException {
        switch (typeCode) {
        case TYPECODE_LONG:
        case TYPECODE_OBJLONG:
            return "NUMERIC";
        case TYPECODE_DOUBLE:
        case TYPECODE_OBJDOUBLE:
            return "DOUBLE PRECISION";
        case TYPECODE_STRING:
        case TYPECODE_CHARARRAY:
            if (size != NOSIZE) {
                return "VARCHAR(" + size + ")";
            }
            return "VARCHAR(" + DEFAULT_VARCHAR_SIZE + ")";
        default:
            return super.getSqlType(typeCode, usedInPK, size, scale);
        }
    }
}